@@ -1,4 +1,5 @@
-.CBIOPORTAL_DATA_URL <- "https://datahub.assets.cbioportal.org/"
+# previously http://download.cbioportal.org
+.url_location <- "https://cbioportal-datahub.s3.amazonaws.com"
 
 getRelevantFilesFromStudy <- function(filelist) {
     ## Remove files that are corrupt / hidden (start with ._)
@@ -130,34 +131,52 @@ cbioportal2clinicaldf <- function(files) {
         inTable
 }
 
-.cache_url_file <- function(url, cache, force = FALSE) {
-    bfc <- BiocFileCache(cache = cache)
-    bquery <- bfcquery(bfc, url, "rname", exact = TRUE)
-    cached <- identical(nrow(bquery), 1L)
+.download_data_file <-
+    function(fileURL, cancer_study_id, verbose = FALSE, force = FALSE)
+{
+    bfc <- .get_cache()
+    rid <- bfcquery(bfc, cancer_study_id, "rname", exact = TRUE)$rid
+    if (!length(rid)) {
+        rid <- names(bfcadd(bfc, cancer_study_id, fileURL, download = FALSE))
+    }
+    if (!.cache_exists(bfc, cancer_study_id) || force) {
+        if (verbose)
+            message("Downloading study file: ", cancer_study_id, ".tar.gz")
+            bfcdownload(bfc, rid, ask = FALSE)
+    } else
+        message("Study file in cache: ", cancer_study_id)
 
-    if (!force && cached)
-        return(
-            bfcrpath(
-                bfc, rnames = url, exact = TRUE, download = TRUE, rtype = "web"
-            )
-        )
+    bfcrpath(bfc, rids = rid)
+}
 
-    destfile <- file.path(cache, basename(url))
-    if (!dir.exists(cache))
-        dir.create(cache, recursive = TRUE, showWarnings = FALSE)
-    download.file(url = url, destfile = destfile)
-    if (!cached)
-        BiocFileCache::bfcadd(
-            x = bfc,
-            rname = url,
-            fpath = destfile,
-            rtype = "local",
-            action = "asis",
-            fname = "exact",
-            exact = TRUE
-        )
-    else
-        destfile
+.manageLocalFile <- function(cancer_study_id, inpath) {
+    bfc <- .get_cache()
+    rid <- bfcquery(bfc, cancer_study_id, "rname", exact = TRUE)$rid
+    if (!length(rid))
+        stop("Can't update non-existing cache item")
+
+    cachedir <- bfccache(bfc)
+    finalname <- paste0(gsub("file", "", basename(tempfile())), "_",
+        cancer_study_id, ".tar.gz")
+    fileLoc <- file.path(cachedir, finalname)
+    file.copy(inpath, fileLoc)
+
+    bfcupdate(bfc, rids = rid, rpath = fileLoc)
+
+    file.remove(inpath)
+
+    bfcrpath(bfc, rids = rid)
+}
+
+.altDownload <- function(fileURL, cancer_study_id, verbose = FALSE) {
+    if (verbose)
+        message("Downloading study file: ", cancer_study_id, ".tar.gz")
+
+    tmpFile <- file.path(tempdir(), paste0(cancer_study_id, ".tar.gz"))
+    utils::download.file(fileURL, destfile = tmpFile, quiet = TRUE,
+        method = "wget")
+
+    .manageLocalFile(cancer_study_id, tmpFile)
 }
 
 #' @name downloadStudy
@@ -231,8 +250,6 @@ cbioportal2clinicaldf <- function(files) {
 #' * untarStudy - The directory location of the contents
 #' * loadStudy - A MultiAssayExperiment-class object
 #'
-#' @importFrom BiocBaseUtils isScalarCharacter
-#'
 #' @seealso [cBioDataPack],
 #'   [MultiAssayExperiment][MultiAssayExperiment::MultiAssayExperiment-class]
 #'
@@ -242,21 +259,31 @@ cbioportal2clinicaldf <- function(files) {
 #'
 #' @export
 downloadStudy <- function(cancer_study_id, use_cache = TRUE, force = FALSE,
-    url_location = getOption("cBio_URL", .CBIOPORTAL_DATA_URL),
-    ask = interactive())
+    url_location = getOption("cBio_URL", .url_location), ask = interactive())
 {
     .validStudyID(cancer_study_id)
 
-    url_file <- paste0(url_location, paste0(cancer_study_id, ".tar.gz"))
+    url_file <- file.path(url_location, paste0(cancer_study_id, ".tar.gz"))
 
-    if (isScalarCharacter(use_cache))
-        cache_dir <- cBioCache(directory = use_cache)
+    if (is.character(use_cache) && length(use_cache) == 1L)
+        cBioCache(directory = use_cache)
     else if (isTRUE(use_cache))
-        cache_dir <- cBioCache(ask = ask)
-    else if (!use_cache)
-        cache_dir <- tempdir()
+        cBioCache(ask = ask)
+    else
+        stop("Use 'setCache' or specify a download location")
 
-    .cache_url_file(url_file, cache_dir, force = force)
+    tryCatch(
+        {
+            .download_data_file(
+                url_file, cancer_study_id, verbose = TRUE, force = force
+            )
+        },
+        error = function(cond) {
+            message("\n", cond)
+            message("\nRetrying download with alternative function...")
+            .altDownload(url_file, cancer_study_id, verbose = TRUE)
+        }
+    )
 }
 
 #' @rdname downloadStudy
@@ -506,10 +533,10 @@ loadStudy <- function(
 #' By default, it points to an Amazon S3 bucket location. Previously, it
 #' pointed to 'http://download.cbioportal.org'. This recent change
 #' (> 2.1.17) should provide faster and more reliable downloads for all users.
-#' See the URL using `cBioPortalData:::.CBIOPORTAL_DATA_URL`. This can be
-#' changed if there are mirrors that host this data by setting the `cBio_URL`
-#' option with `getOption("cBio_URL", "https://some.url.com/")` before running
-#' the function.
+#' See the URL using `cBioPortalData:::.url_location`. This can be changed
+#' if there are mirrors that host this data by setting the `cBio_URL` option
+#' with `getOption("cBio_URL", "https://some.url.com/")` before running the
+#' function.
 #'
 #' @inheritParams downloadStudy
 #' @inheritParams cBioPortalData
