@@ -1,8 +1,7 @@
-.get_cache <- function(directory) {
-    cache <- getOption(
-        "cBioCache", setCache(directory = directory, verbose = FALSE)
-    )
-    BiocFileCache(cache = cache)
+.get_cache <- function() {
+    cache <- getOption("cBioCache", setCache(verbose = FALSE))
+
+    BiocFileCache(cache)
 }
 
 .cache_exists <- function(bfc, rname) {
@@ -160,54 +159,3 @@ removePackCache <- function(cancer_study_id, dry.run = TRUE) {
     digi <- digest::digest(list("clinicalData", api, studyId))
     .getHashCache(digi)
 }
-
-#' @name cBioCache-defunct
-#'
-#' @title Defunct cache helper functions
-#'
-#' @description `cBioPortalData` no longer caches data from API responses;
-#'   therefore, `removeDataCache` is no longer needed. It will be removed
-#'   as soon as the next release of Bioconductor.
-#'
-#' @inheritParams cBioPortalData
-#' @inheritParams cBioPortal
-#' @inheritParams cBioCache
-#'
-#' @importFrom BiocBaseUtils lifeCycle
-#'
-#' @section removeDataCache:
-#' Remove the computed cache location based on the function inputs to
-#' `cBioPortalData()`. To remove the cache, simply replace the
-#' `cBiocPortalData()` function name with `removeDataCache()`; see the example.
-#' If the computed cache location is not found, it will return an empty vector.
-#'
-#' @examples
-#'
-#' cbio <- cBioPortal()
-#'
-#' cBioPortalData(
-#'     cbio, by = "hugoGeneSymbol",
-#'     studyId = "acc_tcga",
-#'     genePanelId = "AmpliSeq",
-#'     molecularProfileIds =
-#'         c("acc_tcga_rppa", "acc_tcga_linear_CNA", "acc_tcga_mutations")
-#' )
-#'
-#' @returns removeDataCache: The path to the cache location when
-#'   `dry.run = FALSE` if the file exists. Otherwise, when `dry.run = TRUE`,
-#'   the function return the output of the `file.remove` operation.
-#'
-#' @export
-removeDataCache <- function(api, studyId = NA_character_,
-    genePanelId = NA_character_, genes = NA_character_,
-    molecularProfileIds = NULL, sampleListId = NULL,
-    sampleIds = NULL,
-    by = c("entrezGeneId", "hugoGeneSymbol"),
-    dry.run = TRUE, ...)
-{
-    lifeCycle(
-        package = "cBioPortalData",
-        title = "cBioCache",
-        cycle = "defunct"
-    )
-}
